"""
Package to access the HBT Salat.
"""

__author__ = "Henning voss"
__copyright__ = "Copyright 2021, Henning Voss"
__license__ = "MIT"
__maintainer__ = "Henning Voss"
__email__ = "henning@huhehu.com"
__status__ = "Production"
